<?php
/**
 * Collection options
 *
 * @package WEN_Commerce
 */

/**
 * Add collection options to theme options
 *
 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
 */
function wen_commerce_collection_options( $wp_customize ) {
	$wp_customize->add_section( 'wen_commerce_collection', array(
			'title' => esc_html__( 'Collection', 'wen-commerce-pro' ),
			'panel' => 'wen_commerce_theme_options',
		)
	);

	// Add color scheme setting and control.
	wen_commerce_register_option( $wp_customize, array(
			'name'              => 'wen_commerce_collection_option',
			'default'           => 'disabled',
			'sanitize_callback' => 'wen_commerce_sanitize_select',
			'choices'           => wen_commerce_section_visibility_options(),
			'label'             => esc_html__( 'Enable on', 'wen-commerce-pro' ),
			'section'           => 'wen_commerce_collection',
			'type'              => 'select',
		)
	);

	wen_commerce_register_option( $wp_customize, array(
			'name'              => 'wen_commerce_collection_layout',
			'default'           => 'layout-two',
			'sanitize_callback' => 'wen_commerce_sanitize_select',
			'active_callback'   => 'wen_commerce_is_collection_active',
			'choices'           => wen_commerce_sections_layout_options(),
			'label'             => esc_html__( 'Layout', 'wen-commerce-pro' ),
			'section'           => 'wen_commerce_collection',
			'type'              => 'select',
		)
	);

	wen_commerce_register_option( $wp_customize, array(
			'name'              => 'wen_commerce_collection_sub_title',
			'sanitize_callback' => 'wp_kses_post',
			'active_callback'   => 'wen_commerce_is_collection_active',
			'label'             => esc_html__( 'Tagline', 'wen-commerce-pro' ),
			'section'           => 'wen_commerce_collection',
			'type'              => 'text',
		)
	);

	wen_commerce_register_option( $wp_customize, array(
			'name'              => 'wen_commerce_collection_archive_title',
			'default'           => esc_html__( 'Collection', 'wen-commerce-pro' ),
			'sanitize_callback' => 'wp_kses_post',
			'active_callback'   => 'wen_commerce_is_collection_active',
			'label'             => esc_html__( 'Title', 'wen-commerce-pro' ),
			'section'           => 'wen_commerce_collection',
			'type'              => 'text',
		)
	);

	wen_commerce_register_option( $wp_customize, array(
			'name'              => 'wen_commerce_collection_description',
			'sanitize_callback' => 'wp_kses_post',
			'active_callback'   => 'wen_commerce_is_collection_active',
			'label'             => esc_html__( 'Description', 'wen-commerce-pro' ),
			'section'           => 'wen_commerce_collection',
			'type'              => 'textarea',
		)
	);

	$type = wen_commerce_section_type_options();

	$type['product'] = esc_html__( 'Products', 'wen-commerce-pro' );

	wen_commerce_register_option( $wp_customize, array(
			'name'              => 'wen_commerce_collection_type',
			'default'           => 'category',
			'sanitize_callback' => 'wen_commerce_sanitize_select',
			'active_callback'   => 'wen_commerce_is_collection_active',
            'choices'           => $type,
			'label'             => esc_html__( 'Type', 'wen-commerce-pro' ),
			'section'           => 'wen_commerce_collection',
			'type'              => 'select',
		)
	);

	wen_commerce_register_option( $wp_customize, array(
			'name'              => 'wen_commerce_collection_number',
			'default'           => 2,
			'sanitize_callback' => 'wen_commerce_sanitize_number_range',
			'active_callback'   => 'wen_commerce_is_collection_active',
			'description'       => esc_html__( 'Save and refresh the page if No. of items is changed (Max no of items: 20)', 'wen-commerce-pro' ),
			'input_attrs'       => array(
				'style' => 'width: 100px;',
				'min'   => 0,
			),
			'label'             => esc_html__( 'No of Items', 'wen-commerce-pro' ),
			'section'           => 'wen_commerce_collection',
			'type'              => 'number',
		)
	);

	wen_commerce_register_option( $wp_customize, array(
			'name'              => 'wen_commerce_collection_meta_show',
			'default'           => 'show-meta',
			'sanitize_callback' => 'wen_commerce_sanitize_select',
			'active_callback'   => 'wen_commerce_is_post_product_category_collection_active',
			'choices'           => wen_commerce_meta_show(),
			'label'             => esc_html__( 'Display Meta', 'wen-commerce-pro' ),
			'section'           => 'wen_commerce_collection',
			'type'              => 'select',
		)
	);


	wen_commerce_register_option( $wp_customize, array(
			'name'              => 'wen_commerce_collection_select_category',
			'sanitize_callback' => 'wen_commerce_sanitize_category_list',
			'custom_control'    => 'WEN_Commerce_Multi_Categories_Control',
			'active_callback'   => 'wen_commerce_is_cat_collection_active',
			'label'             => esc_html__( 'Select Categories', 'wen-commerce-pro' ),
			'name'              => 'wen_commerce_collection_select_category',
			'section'           => 'wen_commerce_collection',
			'type'              => 'dropdown-categories',
		)
	);

	$number = get_theme_mod( 'wen_commerce_collection_number', 2 );

	for ( $i = 1; $i <= $number ; $i++ ) {
		wen_commerce_register_option( $wp_customize, array(
				'name'              => 'wen_commerce_collection_post_' . $i,
				'sanitize_callback' => 'wen_commerce_sanitize_post',
				'default'           => 0,
				'active_callback'   => 'wen_commerce_is_post_collection_active',
				'input_attrs'       => array(
					'style'             => 'width: 40px;'
				),
				'label'             => esc_html__( 'Post', 'wen-commerce-pro' ) . ' ' . $i ,
				'section'           => 'wen_commerce_collection',
				'choices'           => wen_commerce_generate_post_array(),
				'type'              => 'select'
			)
		);

		if ( wen_commerce_is_woocommerce_activated() ) {
			wen_commerce_register_option( $wp_customize, array(
					'name'              => 'wen_commerce_collection_product_' . $i,
					'sanitize_callback' => 'wen_commerce_sanitize_post',
					'active_callback'   => 'wen_commerce_is_product_collection_active',
					'label'             => esc_html__( 'Product', 'wen-commerce-pro' ) . ' ' . $i ,
					'section'           => 'wen_commerce_collection',
					'type'              => 'select',
					'choices'           => wen_commerce_generate_products_array(),
				)
			);
		}

		wen_commerce_register_option( $wp_customize, array(
				'name'              => 'wen_commerce_collection_page_' . $i,
				'sanitize_callback' => 'wen_commerce_sanitize_post',
				'active_callback'   => 'wen_commerce_is_page_collection_active',
				'label'             => esc_html__( 'Page', 'wen-commerce-pro' ) . ' ' . $i ,
				'section'           => 'wen_commerce_collection',
				'type'              => 'dropdown-pages',
			)
		);

		wen_commerce_register_option( $wp_customize, array(
				'name'              => 'wen_commerce_collection_description_' . $i,
				'sanitize_callback' => 'wp_kses_post',
				'active_callback'   => 'wen_commerce_is_custom_collection_inactive',
				'label'             => esc_html__( 'Description', 'wen-commerce-pro' ) . ' ' . $i,
				'section'           => 'wen_commerce_collection',
				'type'              => 'textarea',
			)
		);

		wen_commerce_register_option( $wp_customize, array(
				'name'              => 'wen_commerce_collection_note_' . $i,
				'sanitize_callback' => 'sanitize_text_field',
				'custom_control'    => 'WEN_Commerce_Note_Control',
				'active_callback'   => 'wen_commerce_is_custom_collection_active',
				'label'             => esc_html__( 'Item #', 'wen-commerce-pro' ) .  $i,
				'section'           => 'wen_commerce_collection',
				'type'              => 'description',
			)
		);

		wen_commerce_register_option( $wp_customize, array(
				'name'              => 'wen_commerce_collection_image_' . $i,
				'sanitize_callback' => 'wen_commerce_sanitize_image',
				'custom_control'    => 'WP_Customize_Image_Control',
				'active_callback'   => 'wen_commerce_is_custom_collection_active',
				'label'             => esc_html__( 'Image', 'wen-commerce-pro' ),
				'section'           => 'wen_commerce_collection',
			)
		);

		wen_commerce_register_option( $wp_customize, array(
				'name'              => 'wen_commerce_collection_link_' . $i,
				'sanitize_callback' => 'esc_url_raw',
				'active_callback'   => 'wen_commerce_is_custom_collection_active',
				'label'             => esc_html__( 'Link', 'wen-commerce-pro' ),
				'section'           => 'wen_commerce_collection',
			)
		);

		wen_commerce_register_option( $wp_customize, array(
				'name'              => 'wen_commerce_collection_target_' . $i,
				'sanitize_callback' => 'wen_commerce_sanitize_checkbox',
				'active_callback'   => 'wen_commerce_is_custom_collection_active',
				'label'             => esc_html__( 'Open Link in New Window/Tab', 'wen-commerce-pro' ),
				'section'           => 'wen_commerce_collection',
				'custom_control'    => 'WEN_Commerce_Toggle_Control',
			)
		);

		wen_commerce_register_option( $wp_customize, array(
				'name'              => 'wen_commerce_collection_title_' . $i,
				'sanitize_callback' => 'wp_kses_post',
				'active_callback'   => 'wen_commerce_is_custom_collection_active',
				'label'             => esc_html__( 'Title', 'wen-commerce-pro' ),
				'section'           => 'wen_commerce_collection',
				'type'              => 'text',
			)
		);

		wen_commerce_register_option( $wp_customize, array(
				'name'              => 'wen_commerce_collection_content_' . $i,
				'sanitize_callback' => 'wp_kses_post',
				'active_callback'   => 'wen_commerce_is_custom_collection_active',
				'label'             => esc_html__( 'Content', 'wen-commerce-pro' ),
				'section'           => 'wen_commerce_collection',
				'type'              => 'textarea',
			)
		);

		wen_commerce_register_option( $wp_customize, array(
				'name'              => 'wen_commerce_collection_button_text_' . $i,
				'sanitize_callback' => 'wp_kses_post',
				'active_callback'   => 'wen_commerce_is_collection_active',
				'label'             => esc_html__( 'Button Text', 'wen-commerce-pro' ) . ' ' . $i,
				'section'           => 'wen_commerce_collection',
				'type'              => 'text',
			)
		);
	} // End for().
}
add_action( 'customize_register', 'wen_commerce_collection_options', 10 );

/** Active Callback Functions **/
if( ! function_exists( 'wen_commerce_is_collection_active' ) ) :
	/**
	* Return true if collection is active
	*
	* @since WEN Commerce Pro 1.0
	*/
	function wen_commerce_is_collection_active( $control ) {
		global $wp_query;

		$page_id = $wp_query->get_queried_object_id();

		// Front page display in Reading Settings
		$page_for_posts = get_option('page_for_posts');

		$enable = $control->manager->get_setting( 'wen_commerce_collection_option' )->value();

		//return true only if previwed page on customizer matches the type of content option selected
		return ( 'entire-site' == $enable || ( ( is_front_page() || ( is_home() && $page_for_posts != $page_id ) ) && 'homepage' == $enable )
	);
	}
endif;

if ( ! function_exists( 'wen_commerce_is_post_collection_active' ) ) :
	/**
	* Return true if page content is active
	*
	* @since WEN Commerce Pro 1.0
	*/
	function wen_commerce_is_post_collection_active( $control ) {
		$type = $control->manager->get_setting( 'wen_commerce_collection_type' )->value();

		return ( wen_commerce_is_collection_active( $control ) && 'post' === $type );
	}
endif;

if ( ! function_exists( 'wen_commerce_is_page_collection_active' ) ) :
	/**
	* Return true if page content is active
	*
	* @since WEN Commerce Pro 1.0
	*/
	function wen_commerce_is_page_collection_active( $control ) {
		$type = $control->manager->get_setting( 'wen_commerce_collection_type' )->value();

		return ( wen_commerce_is_collection_active( $control ) && 'page' === $type );
	}
endif;

if ( ! function_exists( 'wen_commerce_is_cat_collection_active' ) ) :
	/**
	* Return true if page content is active
	*
	* @since WEN Commerce Pro 1.0
	*/
	function wen_commerce_is_cat_collection_active( $control ) {
		$type = $control->manager->get_setting( 'wen_commerce_collection_type' )->value();

		return ( wen_commerce_is_collection_active( $control ) && 'category' === $type );
	}
endif;

if ( ! function_exists( 'wen_commerce_is_post_product_category_collection_active' ) ) :
	/**
	* Return true if page/post/category/image content is active
	*
	* @since WEN Commerce Pro 1.0
	*/
	function wen_commerce_is_post_product_category_collection_active( $control ) {
		$type = $control->manager->get_setting( 'wen_commerce_collection_type' )->value();

		return ( wen_commerce_is_collection_active( $control ) && ( 'category' === $type || 'post' === $type || 'product' === $type ) );
	}
endif;

if ( ! function_exists( 'wen_commerce_is_custom_collection_active' ) ) :
	/**
	* Return true if page content is active
	*
	* @since WEN Commerce Pro 1.0
	*/
	function wen_commerce_is_custom_collection_active( $control ) {
		$type = $control->manager->get_setting( 'wen_commerce_collection_type' )->value();

		return ( wen_commerce_is_collection_active( $control ) && 'custom' === $type );
	}
endif;

if ( ! function_exists( 'wen_commerce_is_product_collection_active' ) ) :
	/**
	* Return true if product content is active
	*
	* @since WEN Commerce Pro 1.0
	*/
	function wen_commerce_is_product_collection_active( $control ) {
		$type = $control->manager->get_setting( 'wen_commerce_collection_type' )->value();

		return ( wen_commerce_is_collection_active( $control ) && 'product' === $type );
	}
endif;

if ( ! function_exists( 'wen_commerce_is_custom_collection_inactive' ) ) :
	/**
	* Return true if page content is active
	*
	* @since WEN Commerce Pro 1.0
	*/
	function wen_commerce_is_custom_collection_inactive( $control ) {
		$type = $control->manager->get_setting( 'wen_commerce_collection_type' )->value();

		return ( wen_commerce_is_collection_active( $control ) && 'custom' !== $type );
	}
endif;
