<?php
/**
 * Reservation options
 *
 * @package WEN_Commerce
 */

/**
 * Add Contact options to theme options
 *
 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
 */
function wen_commerce_contact_options( $wp_customize ) {
    $wp_customize->add_section( 'wen_commerce_contact', array(
			'title' => esc_html__( 'Contact', 'wen-commerce-pro' ),
			'panel' => 'wen_commerce_theme_options',
		)
	);

	wen_commerce_register_option( $wp_customize, array(
			'name'              => 'wen_commerce_contact_option',
			'default'           => 'disabled',
			'sanitize_callback' => 'wen_commerce_sanitize_select',
			'choices'           => wen_commerce_section_visibility_options(),
			'label'             => esc_html__( 'Enable on', 'wen-commerce-pro' ),
			'section'           => 'wen_commerce_contact',
			'type'              => 'select',
		)
	);

	$type = wen_commerce_section_type_options();

	unset( $type['category'] );

	wen_commerce_register_option( $wp_customize, array(
			'name'              => 'wen_commerce_contact_type',
			'default'			=> 'page',
			'sanitize_callback' => 'wen_commerce_sanitize_select',
			'active_callback'   => 'wen_commerce_is_contact_active',
            'choices'           => $type,
			'label'             => esc_html__( 'Type', 'wen-commerce-pro' ),
			'section'           => 'wen_commerce_contact',
			'type'              => 'select',
		)
	);

	wen_commerce_register_option( $wp_customize, array(
			'name'              => 'wen_commerce_contact_sub_title',
			'sanitize_callback' => 'wp_kses_post',
			'active_callback'   => 'wen_commerce_is_contact_active',
			'label'             => esc_html__( 'Tagline', 'wen-commerce-pro' ),
			'section'           => 'wen_commerce_contact',
			'type'              => 'text',
		)
	);

	wen_commerce_register_option( $wp_customize, array(
			'name'              => 'wen_commerce_contact_post',
			'sanitize_callback' => 'wen_commerce_sanitize_post',
			'default'           => 0,
			'active_callback'   => 'wen_commerce_is_contact_post_active',
			'input_attrs'       => array(
				'style' => 'width: 40px;'
			),
			'label'             => esc_html__( 'Post', 'wen-commerce-pro' ),
			'section'           => 'wen_commerce_contact',
			'choices'           => wen_commerce_generate_post_array(),
			'type'              => 'select'
		)
	);

	wen_commerce_register_option( $wp_customize, array(
			'name'              => 'wen_commerce_contact_page',
			'sanitize_callback' => 'wen_commerce_sanitize_post',
			'active_callback'   => 'wen_commerce_is_contact_page_active',
			'label'             => esc_html__( 'Page', 'wen-commerce-pro' ),
			'section'           => 'wen_commerce_contact',
			'type'              => 'dropdown-pages',
			'allow_addition'    => true,
		)
	);

	wen_commerce_register_option( $wp_customize, array(
			'name'              => 'wen_commerce_contact_bg_image',
			'sanitize_callback' => 'wen_commerce_sanitize_image',
			'active_callback'   => 'wen_commerce_is_contact_custom_active',
			'custom_control'    => 'WP_Customize_Image_Control',
			'label'             => esc_html__( 'Background Image', 'wen-commerce-pro' ),
			'section'           => 'wen_commerce_contact',
		)
	);

	wen_commerce_register_option( $wp_customize, array(
			'name'              => 'wen_commerce_contact_title',
			'default'           => esc_html__( 'Let\'s get in touch', 'wen-commerce-pro' ),
			'sanitize_callback' => 'sanitize_text_field',
			'active_callback'   => 'wen_commerce_is_contact_custom_active',
			'label'             => esc_html__( 'Title', 'wen-commerce-pro' ),
			'section'           => 'wen_commerce_contact',
			'type'              => 'text',
		)
	);

	wen_commerce_register_option( $wp_customize, array(
			'name'              => 'wen_commerce_contact_description',
			'sanitize_callback' => 'wp_kses_post',
			'active_callback'   => 'wen_commerce_is_contact_active',
			'label'             => esc_html__( 'Description', 'wen-commerce-pro' ),
			'section'           => 'wen_commerce_contact',
			'type'              => 'textarea',
		)
	);

	wen_commerce_register_option( $wp_customize, array(
			'name'              => 'wen_commerce_contact_custom',
			'sanitize_callback' => 'wp_kses_post',
			'description'       => esc_html__( 'Add custom shortcodes from Contact Form 7 or Jetpack', 'wen-commerce-pro' ),
			'active_callback'   => 'wen_commerce_is_contact_custom_active',
			'label'             => esc_html__( 'Custom Content', 'wen-commerce-pro' ),
			'section'           => 'wen_commerce_contact',
			'type'              => 'textarea',
		)
	);
}
add_action( 'customize_register', 'wen_commerce_contact_options', 10 );

if ( ! function_exists( 'wen_commerce_is_contact_active' ) ) :
	/**
	* Return true if reservation is active
	*
	* @since Foodoholic Pro 1.0
	*/
	function wen_commerce_is_contact_active( $control ) {
		$enable = $control->manager->get_setting( 'wen_commerce_contact_option' )->value();

		//return true only if previewed page on customizer matches the type of content option selected
		return ( wen_commerce_check_section( $enable ) );
	}
endif;

if ( ! function_exists( 'wen_commerce_is_contact_post_active' ) ) :
	/**
	* Return true if page content is active
	*
	* @since Foodoholic Pro 1.0
	*/
	function wen_commerce_is_contact_post_active( $control ) {
		$type = $control->manager->get_setting( 'wen_commerce_contact_type' )->value();

		return ( wen_commerce_is_contact_active( $control ) && 'post' === $type );
	}
endif;

if ( ! function_exists( 'wen_commerce_is_contact_page_active' ) ) :
	/**
	* Return true if page content is active
	*
	* @since Foodoholic Pro 1.0
	*/
	function wen_commerce_is_contact_page_active( $control ) {
		$type = $control->manager->get_setting( 'wen_commerce_contact_type' )->value();

		return ( wen_commerce_is_contact_active( $control ) && 'page' === $type );
	}
endif;

if ( ! function_exists( 'wen_commerce_is_contact_custom_active' ) ) :
	/**
	* Return true if custom content is active
	*
	* @since Foodoholic Pro 1.0
	*/
	function wen_commerce_is_contact_custom_active( $control ) {
		$type = $control->manager->get_setting( 'wen_commerce_contact_type' )->value();

		return ( wen_commerce_is_contact_active( $control ) && 'custom' === $type );
	}
endif;
