<?php
/**
 * Stats options
 *
 * @package WEN_Commerce
 */

/**
 * Add skills options to theme options
 *
 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
 */
function wen_commerce_skills_options( $wp_customize ) {
	$wp_customize->add_section( 'wen_commerce_skills', array(
			'title' => esc_html__( 'Skills', 'wen-commerce-pro' ),
			'panel' => 'wen_commerce_theme_options',
		)
	);

	// Add color scheme setting and control.
	wen_commerce_register_option( $wp_customize, array(
			'name'              => 'wen_commerce_skills_option',
			'default'           => 'disabled',
			'sanitize_callback' => 'wen_commerce_sanitize_select',
			'choices'           => wen_commerce_section_visibility_options(),
			'label'             => esc_html__( 'Enable on', 'wen-commerce-pro' ),
			'section'           => 'wen_commerce_skills',
			'type'              => 'select',
		)
	);

	wen_commerce_register_option( $wp_customize, array(
			'name'              => 'wen_commerce_skills_bg_image',
			'sanitize_callback' => 'wen_commerce_sanitize_image',
			'custom_control'    => 'WP_Customize_Image_Control',
			'active_callback'   => 'wen_commerce_is_skills_active',
			'label'             => esc_html__( 'Background Image', 'wen-commerce-pro' ),
			'section'           => 'wen_commerce_skills',
		)
	);

	wen_commerce_register_option( $wp_customize, array(
			'name'              => 'wen_commerce_skills_subtitle',
			'sanitize_callback' => 'sanitize_text_field',
			'active_callback'   => 'wen_commerce_is_skills_active',
			'label'             => esc_html__( 'Tagline', 'wen-commerce-pro' ),
			'section'           => 'wen_commerce_skills',
			'type'              => 'text',
		)
	);

	wen_commerce_register_option( $wp_customize, array(
			'name'              => 'wen_commerce_skills_title',
			'sanitize_callback' => 'sanitize_text_field',
			'active_callback'   => 'wen_commerce_is_skills_active',
			'label'             => esc_html__( 'Title', 'wen-commerce-pro' ),
			'section'           => 'wen_commerce_skills',
			'type'              => 'text',
		)
	);

	wen_commerce_register_option( $wp_customize, array(
			'name'              => 'wen_commerce_skills_description',
			'sanitize_callback' => 'wp_kses_post',
			'active_callback'   => 'wen_commerce_is_skills_active',
			'label'             => esc_html__( 'Description', 'wen-commerce-pro' ),
			'section'           => 'wen_commerce_skills',
			'type'              => 'textarea',
		)
	);

	wen_commerce_register_option( $wp_customize, array(
			'name'              => 'wen_commerce_skills_left_section',
			'sanitize_callback' => 'sanitize_text_field',
			'custom_control'    => 'WEN_Commerce_Note_Control',
			'active_callback'   => 'wen_commerce_is_skills_active',
			'label'             => esc_html__( 'Left Section', 'wen-commerce-pro' ),
			'section'           => 'wen_commerce_skills',
			'type'              => 'description',
		)
	);	

	wen_commerce_register_option( $wp_customize, array(
			'name'              => 'wen_commerce_skills_content_subtitle',
			'sanitize_callback' => 'sanitize_text_field',
			'active_callback'   => 'wen_commerce_is_skills_active',
			'label'             => esc_html__( 'Content Subtitle', 'wen-commerce-pro' ),
			'section'           => 'wen_commerce_skills',
			'type'              => 'text',
		)
	);

	wen_commerce_register_option( $wp_customize, array(
			'name'              => 'wen_commerce_skills_content_title',
			'sanitize_callback' => 'sanitize_text_field',
			'active_callback'   => 'wen_commerce_is_skills_active',
			'label'             => esc_html__( 'Content Title', 'wen-commerce-pro' ),
			'section'           => 'wen_commerce_skills',
			'type'              => 'text',
		)
	);

	wen_commerce_register_option( $wp_customize, array(
			'name'              => 'wen_commerce_skills_content_description',
			'sanitize_callback' => 'wp_kses_post',
			'active_callback'   => 'wen_commerce_is_skills_active',
			'label'             => esc_html__( 'Content Description', 'wen-commerce-pro' ),
			'section'           => 'wen_commerce_skills',
			'type'              => 'textarea',
		)
	);

	wen_commerce_register_option( $wp_customize, array(
			'name'              => 'wen_commerce_skills_more_text',
			'sanitize_callback' => 'sanitize_text_field',
			'active_callback'   => 'wen_commerce_is_skills_active',
			'label'             => esc_html__( 'Button Text', 'wen-commerce-pro' ),
			'section'           => 'wen_commerce_skills',
		)
	);

	wen_commerce_register_option( $wp_customize, array(
			'name'              => 'wen_commerce_skills_more_link',
			'sanitize_callback' => 'esc_url_raw',
			'active_callback'   => 'wen_commerce_is_skills_active',
			'label'             => esc_html__( 'Button Link', 'wen-commerce-pro' ),
			'section'           => 'wen_commerce_skills',
		)
	);

	wen_commerce_register_option( $wp_customize, array(
			'name'              => 'wen_commerce_skills_more_target',
			'sanitize_callback' => 'wen_commerce_sanitize_checkbox',
			'active_callback'   => 'wen_commerce_is_skills_active',
			'label'             => esc_html__( 'Open Link in New Window/Tab', 'wen-commerce-pro' ),
			'section'           => 'wen_commerce_skills',
			'custom_control'    => 'WEN_Commerce_Toggle_Control',
		)
	);

	wen_commerce_register_option( $wp_customize, array(
			'name'              => 'wen_commerce_skills_right_section',
			'sanitize_callback' => 'sanitize_text_field',
			'custom_control'    => 'WEN_Commerce_Note_Control',
			'active_callback'   => 'wen_commerce_is_skills_active',
			'label'             => esc_html__( 'Right Section', 'wen-commerce-pro' ),
			'section'           => 'wen_commerce_skills',
			'type'              => 'description',
		)
	);

	wen_commerce_register_option( $wp_customize, array(
			'name'              => 'wen_commerce_skills_number',
			'default'           => 4,
			'sanitize_callback' => 'wen_commerce_sanitize_number_range',
			'active_callback'   => 'wen_commerce_is_skills_active',
			'description'       => esc_html__( 'Save and refresh the page if No of items is changed', 'wen-commerce-pro' ),
			'input_attrs'       => array(
				'style' => 'width: 100px;',
				'min'   => 0,
			),
			'label'             => esc_html__( 'No of Items', 'wen-commerce-pro' ),
			'section'           => 'wen_commerce_skills',
			'type'              => 'number',
			'transport'         => 'postMessage',
		)
	);

	$number = get_theme_mod( 'wen_commerce_skills_number', 4 );

	for ( $i = 1; $i <= $number ; $i++ ) {
		wen_commerce_register_option( $wp_customize, array(
				'name'              => 'wen_commerce_skills_note_' . $i,
				'sanitize_callback' => 'sanitize_text_field',
				'custom_control'    => 'WEN_Commerce_Note_Control',
				'active_callback'   => 'wen_commerce_is_skills_active',
				'label'             => esc_html__( 'Item #', 'wen-commerce-pro' ) .  $i,
				'section'           => 'wen_commerce_skills',
				'type'              => 'description',
			)
		);

		wen_commerce_register_option( $wp_customize, array(
				'name'              => 'wen_commerce_skills_title_' . $i,
				'sanitize_callback' => 'sanitize_text_field',
				'active_callback'   => 'wen_commerce_is_skills_active',
				'label'             => esc_html__( 'Title', 'wen-commerce-pro' ),
				'section'           => 'wen_commerce_skills',
				'type'              => 'text',
			)
		);

		wen_commerce_register_option( $wp_customize, array(
				'name'              => 'wen_commerce_skills_percentage_' . $i,
				'sanitize_callback' => 'wen_commerce_sanitize_number_range',
				'active_callback'   => 'wen_commerce_is_skills_active',
				'label'             => esc_html__( 'Percentage', 'wen-commerce-pro' ),
				'section'           => 'wen_commerce_skills',
				'type'              => 'number',
					'input_attrs'       => array(
					'style' => 'width: 50px;',
					'min'   => 1,
					'max'   => 100,
				),
			)
		);
	} // End for().
}
add_action( 'customize_register', 'wen_commerce_skills_options', 10 );

/** Active Callback Functions **/
if( ! function_exists( 'wen_commerce_is_skills_active' ) ) :
	/**
	* Return true if stat is active
	*
	* @since 1.0
	*/
	function wen_commerce_is_skills_active( $control ) {
		$enable = $control->manager->get_setting( 'wen_commerce_skills_option' )->value();

		return ( wen_commerce_check_section( $enable ) );
	}
endif;
