<?php
/**
 * Adding support for WooCommerce Products Review Option
 */

/**
 *
 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
 */
function wen_commerce_products_review( $wp_customize ) {
   $wp_customize->add_section( 'wen_commerce_products_review', array(
        'title' => esc_html__( 'WooCommerce Products Review', 'wen-commerce-pro' ),
        'panel' => 'wen_commerce_theme_options',
    ) );

    wen_commerce_register_option( $wp_customize, array(
            'name'              => 'wen_commerce_products_review_option',
            'default'           => 'disabled',
            'sanitize_callback' => 'wen_commerce_sanitize_select',
            'choices'           => wen_commerce_section_visibility_options(),
            'label'             => esc_html__( 'Enable on', 'wen-commerce-pro' ),
            'section'           => 'wen_commerce_products_review',
            'type'              => 'select',
        )
    );

    wen_commerce_register_option( $wp_customize, array(
            'name'              => 'wen_commerce_products_review_layout',
            'default'           => 2,
            'sanitize_callback' => 'wen_commerce_sanitize_select',
            'active_callback'   => 'wen_commerce_is_products_review_active',
            'choices'           => array(
                    '1' => esc_html__( '1 column', 'wen-commerce-pro' ),
                    '2' => esc_html__( '2 columns', 'wen-commerce-pro' ),
                ),
            'label'             => esc_html__( 'Select Products review Layout', 'wen-commerce-pro' ),
            'section'           => 'wen_commerce_products_review',
            'type'              => 'select',
        )
    );


    wen_commerce_register_option( $wp_customize, array(
            'name'              => 'wen_commerce_products_review_slider',
            'default'           => 1,
            'sanitize_callback' => 'wen_commerce_sanitize_checkbox',
            'active_callback'   => 'wen_commerce_is_products_review_active',
            'label'             => esc_html__( 'Check to Enable Slider', 'wen-commerce-pro' ),
            'section'           => 'wen_commerce_products_review',
            'custom_control'    => 'WEN_Commerce_Toggle_Control',
        )
    );

    wen_commerce_register_option( $wp_customize, array(
            'name'              => 'wen_commerce_products_review_tagline',
            'sanitize_callback' => 'wp_kses_post',
            'label'             => esc_html__( 'Tagline', 'wen-commerce-pro' ),
            'active_callback'   => 'wen_commerce_is_products_review_active',
            'section'           => 'wen_commerce_products_review',
            'type'              => 'text',
        )
    );

    wen_commerce_register_option( $wp_customize, array(
            'name'              => 'wen_commerce_products_review_title',
            'sanitize_callback' => 'wp_kses_post',
            'label'             => esc_html__( 'Title', 'wen-commerce-pro' ),
            'active_callback'   => 'wen_commerce_is_products_review_active',
            'section'           => 'wen_commerce_products_review',
            'type'              => 'text',
        )
    );

    wen_commerce_register_option( $wp_customize, array(
            'name'              => 'wen_commerce_woo_products_review_description',
            'sanitize_callback' => 'wp_kses_post',
            'label'             => esc_html__( 'Description', 'wen-commerce-pro' ),
            'active_callback'   => 'wen_commerce_is_products_review_active',
            'section'           => 'wen_commerce_products_review',
            'type'              => 'text',
        )
    );

    wen_commerce_register_option( $wp_customize, array(
            'name'              => 'wen_commerce_products_review_number',
            'default'           => 4,
            'sanitize_callback' => 'wen_commerce_sanitize_number_range',
            'active_callback'   => 'wen_commerce_is_products_review_active',
            'description'       => esc_html__( 'Save and refresh the page if No. of Products is changed. Set -1 to display all', 'wen-commerce-pro' ),
            'input_attrs'       => array(
                'style' => 'width: 50px;',
                'min'   => -1,
            ),
            'label'             => esc_html__( 'No of Reviews', 'wen-commerce-pro' ),
            'section'           => 'wen_commerce_products_review',
            'type'              => 'number',
        )
    );

    wen_commerce_register_option( $wp_customize, array(
            'name'              => 'wen_commerce_products_review_sort',
            'default'           => 'highest-to-lowest',
            'sanitize_callback' => 'wen_commerce_sanitize_select',
            'active_callback'   => 'wen_commerce_is_products_review_active',
            'choices'           => array(
                'highest-to-lowest'     => esc_html__( 'Rating (Highest to Lowest)', 'wen-commerce-pro' ),
                'lowest-to-highest'     => esc_html__( 'Rating (Lowest to Highest)', 'wen-commerce-pro' ),
                'newest' => esc_html__( 'Newest', 'wen-commerce-pro' ),
                'oldest'            => esc_html__( 'Oldest', 'wen-commerce-pro' ),
            ),
            'label'             => esc_html__( 'Sort Reviews By', 'wen-commerce-pro' ),
            'section'           => 'wen_commerce_products_review',
            'type'              => 'select',
        )
    );
} 

add_action( 'customize_register', 'wen_commerce_products_review', 10 );

/** Active Callback Functions **/
if( ! function_exists( 'wen_commerce_is_products_review_active' ) ) :
    /**
    * Return true if featured content is active
    *
    * @since WEN Commerce Pro 1.0
    */
    function wen_commerce_is_products_review_active( $control ) {
        $enable = $control->manager->get_setting( 'wen_commerce_products_review_option' )->value();

        return ( wen_commerce_check_section( $enable ) );
    }
endif;
