<?php
/**
 * The template for displaying the Events
 *
 * @package WEN_Commerce
 */


if ( ! function_exists( 'wen_commerce_events_display' ) ) :
	/**
	* Add Events
	*
	* @uses action hook wen_commerce_before_content.
	*
	* @since WEN Commerce Pro 1.0
	*/
	function wen_commerce_events_display() {
		$enable = get_theme_mod( 'wen_commerce_events_option', 'disabled' );

		if ( wen_commerce_check_section( $enable ) ) {
			$wen_commerce_subtitle    = get_theme_mod( 'wen_commerce_why_choose_us_sub_title' );
			$wen_commerce_title       = get_theme_mod( 'wen_commerce_why_choose_us_title' );
			$wen_commerce_description = get_theme_mod( 'wen_commerce_why_choose_us_description' );
			$content_select 	  = get_theme_mod( 'wen_commerce_events_type', 'category' );
			$background           = get_theme_mod( 'wen_commerce_events_bg_image' );

			$classes[] = $content_select;

			if ( $background ) {
				$classes[] = 'has-background-image';
			}

			if ( ! $wen_commerce_subtitle && ! $wen_commerce_title && ! $wen_commerce_description ) {
				$classes[] = 'no-section-heading';
			}
			
			$output ='
				<div id="events-section" class="events-section section ' . esc_attr( implode( ' ', $classes ) ) . '">
					<div class="wrapper">';
						if ( $wen_commerce_subtitle || $wen_commerce_title || $wen_commerce_description ) {
							$output .='<div class="section-heading-wrapper">';

								if( $wen_commerce_subtitle ) {
									$output .='<div class="section-subtitle">' . esc_html( $wen_commerce_subtitle ) . '</div>';
								}

								if ( $wen_commerce_title ) {
									$output .='<div class="section-title-wrapper">
										<h2 class="section-title"wen_commerce_>' . wp_kses_post( $wen_commerce_title ) . '</h2>
									</div><!-- .page-title-wrapper -->';
								}

								if ( $wen_commerce_description ) {
									$output .='<div class="section-description">
										<p>' . wp_kses_post( $wen_commerce_description ) . '</p>
									</div><!-- .section-description-wrapper -->';
								}
							$output .='</div><!-- .section-heading-wrapper -->';
						}

						$output .='
						<div class="events-content-wrapper section-content-wrapper">';

						$output .='<div class="events-article-wrapper">';
					
						if ( 'post' === $content_select || 'page' === $content_select || 'category' === $content_select ) {
							$output .= wen_commerce_post_page_category_events();
						} elseif ( 'custom' === $content_select ) {
							$output .= wen_commerce_custom_events();
						}
						
						$output .='</div><!-- .events-article-wrapper -->';

			$target = get_theme_mod( 'wen_commerce_events_target' ) ? '_blank': '_self';
			$link   = get_theme_mod( 'wen_commerce_events_link', '#' );
			$text   = get_theme_mod( 'wen_commerce_events_text' );
			$output .='</div><!-- .section-content-wrap -->';

			if ( $text ) {
				$output .= '
				<p class="view-more">
					<a class="button" target="' . $target . '" href="' . esc_url( $link ) . '">' . esc_html( $text ) . '</a>
				</p>';
			}
					$output .='</div><!-- .wrapper -->
				</div><!-- #events-section -->';

			echo $output;
		}
	}
endif;

if ( ! function_exists( 'wen_commerce_post_page_category_events' ) ) :
	/**
	 * Display Page/Post/Category Events
	 *
	 * @since WEN Commerce Pro 1.0
	 */
	function wen_commerce_post_page_category_events() {
		global $post;

		$quantity   = get_theme_mod( 'wen_commerce_events_number', 3 );
		$no_of_post = 0; // for number of posts
		$post_list  = array();// list of valid post/page ids
		$type       = get_theme_mod( 'wen_commerce_events_type', 'category' );
		$output     = '';

		$args = array(
			'post_type'           => 'any',
			'orderby'             => 'post__in',
			'ignore_sticky_posts' => 1 // ignore sticky posts
		);

		//Get valid number of posts
		if ( 'post' == $type || 'page' == $type  ) {
			for( $i = 1; $i <= $quantity; $i++ ){
				$post_id = '';

				if ( 'post' == $type ) {
					$post_id = get_theme_mod( 'wen_commerce_events_post_' . $i );
				} elseif ( 'page' == $type ) {
					$post_id = get_theme_mod( 'wen_commerce_events_page_' . $i ) ;
				}

				if ( $post_id ) {
					if ( class_exists( 'Polylang' ) ) {
						$post_id = pll_get_post( $post_id, pll_current_language() );
					}

					$post_list = array_merge( $post_list, array( $post_id ) );

					$no_of_post++;
				}
			}

			$args['post__in'] = $post_list;
		} elseif ( 'category' == $type ) {
			$no_of_post = $quantity;

			if ( get_theme_mod( 'wen_commerce_events_select_category' ) ) {
				$args['category__in'] = (array) get_theme_mod( 'wen_commerce_events_select_category' );
			}

			$args['post_type'] = 'post';
		}

		if ( 0 == $no_of_post ) {
			return;
		}

		$args['posts_per_page'] = $no_of_post;

		$loop = new WP_Query( $args );

		while ( $loop->have_posts() ) {
			$loop->the_post();

			$title_attribute = the_title_attribute( 'echo=0' );

				$output .= '
				<article id="event-post-' . esc_attr( $loop->current_post + 1 ) . '" class="event-list-item post hentry post">
					<div class="entry-container">';

				if ( get_theme_mod( 'wen_commerce_events_display_date', 1 ) ) {
					$event_date_day        = get_the_date( 'j' );
					$event_date_month      = get_the_date( 'M' );
					$event_date_year       = get_the_date( 'Y' );
					$event_date_day_meta   = get_post_meta( $post->ID, 'wen-commerce-event-date-day', true );
					$event_date_month_meta = get_post_meta( $post->ID, 'wen-commerce-event-date-month', true );
					$event_date_year_meta  = get_post_meta( $post->ID, 'wen-commerce-event-date-year', true );

					if ( '' !== $event_date_day_meta ) {
						$event_date_day = $event_date_day_meta;
					}

					if ( '' !== $event_date_month_meta ) {
						$event_date_month = $event_date_month_meta;
					}

					if ( '' !== $event_date_year_meta ) {
						$event_date_year = $event_date_year_meta;
					}

					$event_date_month = date( 'M', mktime(0, 0, 0, absint( $event_date_month ), 10 ) );

					$output .= '<div class="entry-meta"><span class="posted-on"><a href="' . esc_url( get_permalink() ) . '" rel="bookmark"><time class="entry-date">
							<span class="date-week-day">' . esc_html( $event_date_day ) . '</span>
							<div class="date-month-year">
								<span class="date-month">' . esc_html( $event_date_month ) . '</span>
								<span class="date-year">' . esc_html( $event_date_year ) . '</span>
							</div>
						</time></a></span></div>';
				}

				$output .= '<div class="event-list-description">';

				if ( get_theme_mod( 'wen_commerce_events_enable_title', 1 ) ) {
					$output .= '
					<div class="event-title">
						<h2 class="entry-title">
							' . the_title( '<a href="' . esc_url( get_permalink() ) . '" rel="bookmark">','</a>', false ) . '
						</h2>
					</div>';
				}

				$text = get_theme_mod( 'wen_commerce_events_individual_text_' . absint( $loop->current_post + 1 )  );

				$content = wpautop( get_the_content() );
				$content = str_replace( ']]>', ']]&gt;', $content );

				$output .= '<div class="entry-summary">' . wp_kses_post( $content ) . '<a href="' . esc_url( get_permalink() ) . '" rel="bookmark" class="more-link">' . esc_html( $text ) . '</a></div><!-- .entry-summary -->';

				$output .= '</div><!-- .event-list-description -->';				

				$output .= '
					</div><!-- .entry-container -->
				</article><!-- .event-post-' . esc_attr( $loop->current_post + 1 ) . ' -->';
			} //endwhile

		wp_reset_postdata();

		return $output;
	}
endif; // wen_commerce_post_page_category_events


if ( ! function_exists( 'wen_commerce_custom_events' ) ) :
	/**
	 * Display Custom Events
	 *
	 * @since WEN Commerce Pro 1.0
	 */
	function wen_commerce_custom_events() {
		$quantity = get_theme_mod( 'wen_commerce_events_number', 3 );
		$output   = '';

		for ( $i = 1; $i <= $quantity; $i++ ) {
			$target = get_theme_mod( 'wen_commerce_events_target_' . $i ) ? '_blank' : '_self';

			$link = get_theme_mod( 'wen_commerce_events_link_' . $i, '#' );

			//support qTranslate plugin
			if ( function_exists( 'qtrans_convertURL' ) ) {
				$link = qtrans_convertURL( $link );
			}

			$title   = get_theme_mod( 'wen_commerce_events_title_' . $i );
			$content = get_theme_mod( 'wen_commerce_events_content_' . $i );
			$text    = get_theme_mod( 'wen_commerce_events_individual_text_' . $i );

			if ( class_exists( 'Polylang' ) ) {
				$title = pll__( $title );
			}

			$date_day = get_theme_mod( 'wen_commerce_events_date_day_' . $i );

			$date_month = get_theme_mod( 'wen_commerce_events_date_month_' . $i );

			$date_year = get_theme_mod( 'wen_commerce_events_date_year_' . $i, '2019' );

			if ( $date_month ) {
				// Convert 1 to Jan, 2 to Feb and so on
				$date_month = date( 'M', mktime(0, 0, 0, $date_month, 10 ) );
			}

			$output .= '
				<article id="event-post-' . esc_html( $i ) . '" class="event-list-item post hentry image">
					<div class="entry-container">';

					if ( $date_day || $date_month || $date_year ) {
						$output .= '<div class="entry-meta"><span class="posted-on"><a target="' . $target . '" href="' . esc_url( $link ) . '" rel="bookmark">
							<time class="entry-date">
								<span class="date-week-day">' . esc_html( $date_day ) . '</span>
								<div class="date-month-year">
									<span class="date-month">' . esc_html( $date_month ) . '</span>
									<span class="date-year">' . esc_html( $date_year ) . '</span>
								</div>
							</time>
						</a></span></div>';
					}

					if ( $title || $content || $text ) {
						$output .= '<div class="event-list-description">';
					}

					if ( $title ) {
						$output .= '
								<div class="event-title">
									<h2 class="entry-title">
										' . wp_kses_post( $title ) . '
									</h2>
								</div>';
					}

					
						
					if ( $content || $text ) {
						$output .= '<div class="entry-summary">';

						if ( $content ) {
							$output .= '<p>' . $content . '</p>';
						}
						
						if ( $text ) {
							$output .= '<a href="' . esc_url( $link ) . '" target="' . $target . '" rel="bookmark" class="more-link">' . esc_html( $text ) . '</a>';
						}

						$output .= '</div><!-- .entry-summary -->';
						
					}

					if ( $title || $content ) {
						$output .= '</div><!-- .event-list-description -->';
					}



				$output .= '
					</div><!-- .entry-container -->
				</article><!-- .event-post-' . esc_attr( $i ) . ' -->';
		}
		return $output;
	}
endif; //wen_commerce_custom_events
