<?php
/**
 * The template for displaying featured content
 *
 * @package WEN_Commerce
 */
?>

<?php
$wen_commerce_enable_content = get_theme_mod( 'wen_commerce_featured_content_option', 'disabled' );

if ( ! wen_commerce_check_section( $wen_commerce_enable_content ) ) {
	// Bail if featured content is disabled.
	return;
}

$wen_commerce_type = get_theme_mod( 'wen_commerce_featured_content_type', 'category' );

if ( 'featured-content' === $wen_commerce_type ) {
	$wen_commerce_title       = get_option( 'featured_content_title', esc_html__( 'Contents', 'wen-commerce-pro' ) );
	$wen_commerce_description = get_option( 'featured_content_content' );
} else {
	$wen_commerce_title       = get_theme_mod( 'wen_commerce_featured_content_title' );
	$wen_commerce_description = get_theme_mod( 'wen_commerce_featured_content_description' );
}

$wen_commerce_layout            = get_theme_mod( 'wen_commerce_featured_content_layout', 'layout-three' );
$wen_commerce_subtitle = get_theme_mod( 'wen_commerce_featured_content_sub_title' ); 

$wen_commerce_classes[] = $wen_commerce_layout;
$wen_commerce_classes[] = $wen_commerce_type;
$wen_commerce_classes[] = 'section';

if ( ! $wen_commerce_title && ! $wen_commerce_subtitle && ! $wen_commerce_description ) {
	$wen_commerce_classes[] = 'no-section-heading';
}
?>

<div id="featured-content-section" class="featured-content-section <?php echo esc_attr( implode( ' ', $wen_commerce_classes ) ); ?>">
	<div class="wrapper">
		<?php if ( $wen_commerce_subtitle || $wen_commerce_title || $wen_commerce_description ) : ?>
			<div class="section-heading-wrapper">

				<?php if( $wen_commerce_subtitle ) : ?>
					<div class="section-subtitle">
						<?php echo esc_html( $wen_commerce_subtitle ); ?>
					</div>
				<?php endif; ?>

				<?php if ( $wen_commerce_title ) : ?>
					<div class="section-title-wrapper">
						<h2 class="section-title"><?php echo wp_kses_post( $wen_commerce_title ); ?></h2>
					</div><!-- .page-title-wrapper -->
				<?php endif; ?>

				<?php if ( $wen_commerce_description ) : ?>
					<div class="section-description">
						<p>
							<?php
								echo wp_kses_post( $wen_commerce_description );
							?>
						</p>
					</div><!-- .section-description-wrapper -->
				<?php endif; ?>
			</div><!-- .section-heading-wrapper -->
		<?php endif; ?>

		<div class="section-content-wrapper featured-content-wrapper <?php echo esc_attr( $wen_commerce_layout ); ?>">
			<?php
				if ( 'custom' === $wen_commerce_type ) {
					get_template_part( 'template-parts/featured-content/custom-featured' );
				} else {
					get_template_part( 'template-parts/featured-content/content-featured' );
				}
			?>
		</div><!-- .section-content-wrap -->

		<?php
			$wen_commerce_target        = get_theme_mod( 'wen_commerce_featured_content_target' ) ? '_blank': '_self';
			$wen_commerce_link = get_theme_mod( 'wen_commerce_featured_content_link', '#' );
			$wen_commerce_text          = get_theme_mod( 'wen_commerce_featured_content_text' );

			if ( $wen_commerce_text ) :
			?>
			<p class="view-more">
				<a class="button" target="<?php echo $wen_commerce_target; ?>" href="<?php echo esc_url( $wen_commerce_link ); ?>"><?php echo esc_html( $wen_commerce_text ); ?></a>
			</p>
		<?php endif; ?>
	</div><!-- .wrapper -->
</div><!-- #featured-content-section -->
