<?php
/**
 * The template for displaying Woo Products Review
 *
 * @package WEN_Commerce
 */

if ( ! class_exists( 'WooCommerce' ) ) {
    // Bail if WooCommerce is not installed
    return;
}

$wen_commerce_enable_content = get_theme_mod( 'wen_commerce_products_review_option', 'disabled' );

$wen_commerce_number = get_theme_mod( 'wen_commerce_products_review_number', 4 );

if ( ! wen_commerce_check_section( $wen_commerce_enable_content ) ) {
	// Bail if featured content is disabled.
	return;
}

$wen_commerce_subtitle 	 = get_theme_mod( 'wen_commerce_products_review_tagline' );
$wen_commerce_title = get_theme_mod( 'wen_commerce_products_review_title' );
$wen_commerce_description = get_theme_mod( 'wen_commerce_woo_products_review_description');


$wen_commerce_layouts = get_theme_mod( 'wen_commerce_products_review_layout', 2 );

$wen_commerce_classes[] = 'section product-review-section testimonial-content-section';

if ( ! $wen_commerce_title && ! $wen_commerce_subtitle && ! $wen_commerce_description) {
	$wen_commerce_classes[] = 'no-headline';
}

?>

<div id="product-review-section" class="<?php echo esc_attr( implode( ' ', $wen_commerce_classes ) ); ?>">
	<div class="wrapper">
		<?php if ( $wen_commerce_title || $wen_commerce_subtitle || $wen_commerce_description ) : ?>
			<div class="section-heading-wrapper product-review-section-headline">
			<?php if ( $wen_commerce_subtitle ) : ?>
					<div class="section-subtitle">
						<?php echo esc_html( $wen_commerce_subtitle); ?>
					</div>
				<?php endif; ?>

				<?php if ( $wen_commerce_title ) : ?>
					<div class="section-title-wrapper">
						<h2 class="section-title"><?php echo wp_kses_post( $wen_commerce_title ); ?></h2>
					</div><!-- .section-title-wrapper -->
				<?php endif; ?>

				<?php if ( $wen_commerce_description ) : ?>
					<div class="section-description">
						<p>
							<?php
								echo wp_kses_post( $wen_commerce_description );
							?>
						</p>	
					</div><!-- .section-description-wrapper -->
				<?php endif; ?>
			</div><!-- .section-heading-wrapper -->
		<?php endif; 

		$wen_commerce_slider_select = get_theme_mod( 'wen_commerce_products_review_slider', 1 );

		$wen_commerce_class[] = 'section-content-wrapper product-review-content-wrapper';

		if( ! $wen_commerce_slider_select ) {
			if( 1 == $wen_commerce_layouts ) {
				$wen_commerce_class[] = 'layout-one';
			} else {
				$wen_commerce_class[] = 'layout-two';
			}
		} else {
			$wen_commerce_class[] = 'product-review-slider owl-carousel';

			if( 1 == $wen_commerce_layouts ) {
				$wen_commerce_class[] = 'layout-one';
			}
		}	

		?>

		<div class="<?php echo esc_attr( implode( ' ', $wen_commerce_class ) ); ?>">
			<?php
				$wen_commerce_review_sort = get_theme_mod( 'wen_commerce_products_review_sort', 'highest-to-lowest' );
			
				$wen_commerce_args = array(
				    'status'   		=> 'approve',
				    'post_status' 	=> 'publish',
				    'post_type'   	=> 'product',
				    'number'     	=> $wen_commerce_number,
				    
			  	);

				if( 'highest-to-lowest' == $wen_commerce_review_sort ) {
					$wen_commerce_args['orderby'] = 'meta_value_num';
					$wen_commerce_args['meta_key'] = 'rating';
					$wen_commerce_args['order'] = 'DESC';
				}
				elseif('lowest-to-highest' == $wen_commerce_review_sort) {
					$wen_commerce_args['orderby'] = 'meta_value_num';
					$wen_commerce_args['meta_key'] = 'rating';
					$wen_commerce_args['order'] = 'ASC';
				}
				elseif( 'oldest' == $wen_commerce_review_sort ) {
					$wen_commerce_args['order'] = 'ASC';
				}
				else {
					$wen_commerce_args['order'] = 'DESC';
				}

			$wen_commerce_comment_query = new WP_Comment_Query;
			$wen_commerce_comments      = $wen_commerce_comment_query->query( $wen_commerce_args );
			
			foreach ( $wen_commerce_comments as $wen_commerce_comment ) {
				get_template_part( 'template-parts/product-review/content', 'review' );
			}

			wp_reset_postdata();
			?>
		</div><!-- .section-content-wrapper -->
	</div><!-- .wrapper -->
</div><!-- .product-review-section -->
