<?php
/**
 * The template for displaying service posts on the front page
 *
 * @package WEN_Commerce
 */

$wen_commerce_show_content  = get_theme_mod( 'wen_commerce_service_show', 'excerpt' );
$wen_commerce_show_meta     = get_theme_mod( 'wen_commerce_service_meta_show', 'hide-meta' );
$wen_commerce_type = get_theme_mod( 'wen_commerce_service_type', 'category' );
$wen_commerce_number        = get_theme_mod( 'wen_commerce_service_number', 3 );

$wen_commerce_post_list  = array();
$wen_commerce_no_of_post = 0;

$wen_commerce_args = array(
	'post_type'           => 'post',
	'ignore_sticky_posts' => 1, // ignore sticky posts.
);

// Get valid number of posts.
if ( 'post' === $wen_commerce_type || 'page' === $wen_commerce_type || 'ect-service' === $wen_commerce_type ) {
	$wen_commerce_args['post_type'] = $wen_commerce_type;

	for ( $wen_commerce_i = 1; $wen_commerce_i <= $wen_commerce_number; $wen_commerce_i++ ) {
		$wen_commerce_post_id = '';

		if ( 'post' === $wen_commerce_type ) {
			$wen_commerce_post_id = get_theme_mod( 'wen_commerce_service_post_' . $wen_commerce_i );
		} elseif ( 'page' === $wen_commerce_type ) {
			$wen_commerce_post_id = get_theme_mod( 'wen_commerce_service_page_' . $wen_commerce_i );
		} elseif ( 'ect-service' === $wen_commerce_type ) {
			$wen_commerce_post_id = get_theme_mod( 'wen_commerce_service_cpt_' . $wen_commerce_i );
		}

		if ( $wen_commerce_post_id ) {
			$wen_commerce_post_list = array_merge( $wen_commerce_post_list, array( $wen_commerce_post_id ) );

			$wen_commerce_no_of_post++;
		}
	}

	$wen_commerce_args['post__in'] = $wen_commerce_post_list;
	$wen_commerce_args['orderby']  = 'post__in';
} elseif ( 'category' === $wen_commerce_type ) {
	if ( $wen_commerce_cat = get_theme_mod( 'wen_commerce_service_select_category' ) ) {
		$wen_commerce_args['category__in'] = $wen_commerce_cat;
	}

	$wen_commerce_no_of_post = $wen_commerce_number;
}

$wen_commerce_args['posts_per_page'] = $wen_commerce_no_of_post;

if ( ! $wen_commerce_no_of_post ) {
	return;
}

$wen_commerce_loop = new WP_Query( $wen_commerce_args );

while ( $wen_commerce_loop->have_posts() ) :
	
	$wen_commerce_loop->the_post();
	$wen_commerce_no_thumb = trailingslashit( esc_url ( get_template_directory_uri() ) ) . '/images/no-thumb-80x80.jpg';
	?>
	<article id="post-<?php the_ID(); ?>" <?php post_class(); ?>>
		<div class="hentry-inner">
			<?php if( has_post_thumbnail() ) : ?>
				<div class="post-thumbnail">
					<a class="cover-link" href="<?php the_permalink(); ?>" title="<?php the_title(); ?>">
						<img src="<?php the_post_thumbnail_url( array( 80, 80 ) ); ?>">
					</a>
				</div>
			<?php else : ?>
				<div class="post-thumbnail">
					<a class="cover-link" href="<?php the_permalink(); ?>" title="<?php the_title(); ?>">
						<img src="<?php echo esc_url( $wen_commerce_no_thumb ); ?>">
					</a>
				</div>
			<?php endif; ?>

			<div class="entry-container">
				<header class="entry-header">
					<?php if ( 'show-meta' === $wen_commerce_show_meta  && ( 'ect-service' == $wen_commerce_type || 'post' === $wen_commerce_type || 'category' === $wen_commerce_type ) ) : ?>
						<div class="entry-category">
							<?php wen_commerce_cat_list(); ?>
						</div>
					<?php endif; ?>
					<?php the_title( '<h2 class="entry-title"><a href="' . esc_url( get_permalink() ) . '" rel="bookmark">','</a></h2>' ); ?>

					<?php if ( 'show-meta' === $wen_commerce_show_meta  && 'custom' !== $wen_commerce_type ) : ?>
					<div class="entry-meta">
						<?php wen_commerce_posted_on(); ?>
					</div><!-- .entry-meta -->
					<?php endif; ?>

				</header>

				<?php wen_commerce_content_display( $wen_commerce_show_content ); ?>
			</div><!-- .entry-container -->
		</div> <!-- .hentry-inner -->
	</article> <!-- .article -->
	<?php
endwhile;

wp_reset_postdata();
