<?php
/**
 * The template for displaying service content
 *
 * @package WEN_Commerce
 */
?>

<?php
$wen_commerce_enable_content    = get_theme_mod( 'wen_commerce_service_option', 'disabled' );
$wen_commerce_text_alignment    = get_theme_mod( 'wen_commerce_service_text_alignment', 'text-align-left' );
$wen_commerce_subtitle = get_theme_mod( 'wen_commerce_service_sub_title' );

if ( ! wen_commerce_check_section( $wen_commerce_enable_content ) ) {
	// Bail if service content is disabled.
	return;
}

$wen_commerce_type = get_theme_mod( 'wen_commerce_service_type', 'category' );

if ( 'ect-service' === $wen_commerce_type ) {
	$wen_commerce_title       = get_option( 'ect_service_title', esc_html__( 'Services', 'wen-commerce-pro' ) );
	$wen_commerce_description = get_option( 'ect_service_content' );
} else {
	$wen_commerce_title       = get_theme_mod( 'wen_commerce_service_title' );
	$wen_commerce_description = get_theme_mod( 'wen_commerce_service_description' );
}

$wen_commerce_classes[] = 'service-section';
$wen_commerce_classes[] = 'section';
$wen_commerce_classes[] = $wen_commerce_text_alignment;

if ( ! $wen_commerce_title && ! $wen_commerce_subtitle && ! $wen_commerce_description ) {
	$wen_commerce_classes[] = 'no-section-heading';
}
?>

<div id="service-section" class="<?php echo esc_attr( implode( ' ', $wen_commerce_classes ) ); ?>">
	<div class="wrapper">
		<?php if ( $wen_commerce_subtitle || $wen_commerce_title || $wen_commerce_description ) : ?>
			<div class="section-heading-wrapper">

				<?php if( $wen_commerce_subtitle ) : ?>
					<div class="section-subtitle">
						<?php echo esc_html( $wen_commerce_subtitle ); ?>
					</div>
				<?php endif; ?>

				<?php if ( $wen_commerce_title ) : ?>
					<div class="section-title-wrapper">
						<h2 class="section-title"wen_commerce_><?php echo wp_kses_post( $wen_commerce_title ); ?></h2>
					</div><!-- .page-title-wrapper -->
				<?php endif; ?>

				<?php if ( $wen_commerce_description ) : ?>
					<div class="section-description">
						<p>
							<?php
								echo wp_kses_post( $wen_commerce_description );
							?>
						</p>
					</div><!-- .section-description-wrapper -->
				<?php endif; ?>
			</div><!-- .section-heading-wrapper -->
		<?php endif; ?>

		<?php

		$wen_commerce_wrapper_classes[] = 'section-content-wrapper service-content-wrapper';

		$wen_commerce_wrapper_classes[] = get_theme_mod( 'wen_commerce_service_layout', 'layout-three' );
		?>

		<div class="<?php echo esc_attr( implode( ' ', $wen_commerce_wrapper_classes ) ); ?>">
			<?php
			if ( 'custom' === $wen_commerce_type ) {
				get_template_part( 'template-parts/service/content-custom' );
			} else {
				get_template_part( 'template-parts/service/content-service' );
			}
			?>

			<?php
				$wen_commerce_target        = get_theme_mod( 'wen_commerce_service_target' ) ? '_blank': '_self';
				$wen_commerce_link = get_theme_mod( 'wen_commerce_service_link', '#' );
				$wen_commerce_text          = get_theme_mod( 'wen_commerce_service_text' );

				if ( $wen_commerce_text ) :
			?>

			<p class="view-more">
				<a class="button" target="<?php echo $wen_commerce_target; ?>" href="<?php echo esc_url( $wen_commerce_link ); ?>"><?php echo esc_html( $wen_commerce_text ); ?></a>
			</p>
			<?php endif; ?>
		</div><!-- .service-wrapper -->
	</div><!-- .wrapper -->
</div><!-- #service-section -->
