<?php
/**
 * The template for displaying team content
 *
 * @package WEN_Commerce
 */
?>

<?php
$wen_commerce_enable_content = get_theme_mod( 'wen_commerce_team_option', 'disabled' );

if ( ! wen_commerce_check_section( $wen_commerce_enable_content ) ) {
	// Bail if team content is disabled.
	return;
}

$wen_commerce_type        = get_theme_mod( 'wen_commerce_team_type', 'category' );
$wen_commerce_title       = get_theme_mod( 'wen_commerce_team_title' );
$wen_commerce_subtitle    = get_theme_mod( 'wen_commerce_team_sub_title' );
$wen_commerce_description = get_theme_mod( 'wen_commerce_team_description' );
$wen_commerce_show_content             = get_theme_mod( 'wen_commerce_team_show', 'hide-content' );
$wen_commerce_show_meta                = get_theme_mod( 'wen_commerce_team_meta_show', 'hide-meta' );
$wen_commerce_layout                   = get_theme_mod( 'wen_commerce_team_layout', 'layout-three' );

$wen_commerce_classes[] = 'section';

if( ! $wen_commerce_title && ! $wen_commerce_description && ! $wen_commerce_subtitle ) {
 	$wen_commerce_classes[] = 'no-section-heading';
}

?>

<div id="team-content-section" class="team-content-section <?php echo esc_attr( implode( ' ', $wen_commerce_classes ) ); ?>">
	<div class="wrapper">
		<?php if ( $wen_commerce_subtitle || $wen_commerce_title || $wen_commerce_description ) : ?>
			<div class="section-heading-wrapper">

				<?php if( $wen_commerce_subtitle ) : ?>
					<div class="section-subtitle">
						<?php echo esc_html( $wen_commerce_subtitle ); ?>
					</div>
				<?php endif; ?>

				<?php if ( $wen_commerce_title ) : ?>
					<div class="section-title-wrapper">
						<h2 class="section-title"wen_commerce_><?php echo wp_kses_post( $wen_commerce_title ); ?></h2>
					</div><!-- .page-title-wrapper -->
				<?php endif; ?>

				<?php if ( $wen_commerce_description ) : ?>
					<div class="section-description">
						<p>
							<?php
								echo wp_kses_post( $wen_commerce_description );
							?>
						</p>
					</div><!-- .section-description-wrapper -->
				<?php endif; ?>
			</div><!-- .section-heading-wrapper -->
		<?php endif; ?>

		<div class="section-content-wrapper team-content-wrapper <?php echo esc_attr( $wen_commerce_layout ); ?>">
			<?php
			$wen_commerce_number = get_theme_mod( 'wen_commerce_team_number', 3 );
			
			if ( 'custom' === $wen_commerce_type ) {
				for ( $wen_commerce_i = 1; $wen_commerce_i <= $wen_commerce_number; $wen_commerce_i++ ) {
					$wen_commerce_target = get_theme_mod( 'wen_commerce_team_target_' . $wen_commerce_i ) ? '_blank' : '_self';
					$wen_commerce_image = get_theme_mod( 'wen_commerce_team_image_' . $wen_commerce_i ) ? get_theme_mod( 'wen_commerce_team_image_' . $wen_commerce_i ) : '';
					$wen_commerce_link = get_theme_mod( 'wen_commerce_team_link_' . $wen_commerce_i ) ? get_theme_mod( 'wen_commerce_team_link_' . $wen_commerce_i ) : '#';

					if ( function_exists( 'qtrans_convertURL' ) ) {
						$wen_commerce_link = qtrans_convertURL( $wen_commerce_link );
					}

					echo '
					<article id="team-post-' . esc_attr( $wen_commerce_i ) . '" class="hentry"> <div class="hentry-inner">';

						$wen_commerce_title = get_theme_mod( 'wen_commerce_team_title_' . $wen_commerce_i );
						$wen_commerce_position           = get_theme_mod( 'wen_commerce_team_position_' . $wen_commerce_i );
						$wen_commerce_content            = get_theme_mod( 'wen_commerce_team_content_' . $wen_commerce_i );
						$wen_commerce_more_button        = get_theme_mod( 'wen_commerce_team_more_button_text_' . $wen_commerce_i );

						echo '
							<div class="post-thumbnail">
								<a href="' . esc_url( $wen_commerce_link ) . '" target="' . esc_attr( $wen_commerce_target ) . '">
									<img src="' . esc_url( $wen_commerce_image ) . '" class="wp-post-image" alt="' . esc_attr( $wen_commerce_title ) . '" title="' . esc_attr( $wen_commerce_title ) . '">
								</a>
							</div>'; ?>

						<?php if ( $wen_commerce_title || $wen_commerce_content || $wen_commerce_more_button) {
							echo '
							<div class="entry-container">
								<header class="entry-header">';

								if ( $wen_commerce_position ) {
									echo '
									<div class="entry-meta">
										<span class="entry-job">
				                        	<span class="job-label">' . esc_html( $wen_commerce_position ) . '</span>
					                    </span>
					                </div> <!-- .entry-meta -->';
					            }

								if ( $wen_commerce_title ) {
									echo '
									<h2 class="entry-title">
										<a href="' . esc_url( $wen_commerce_link ) . '" rel="bookmark" target="' . esc_attr( $wen_commerce_target ) . '">' . wp_kses_post( $wen_commerce_title ) . '</a>
									</h2>';
								}

								echo '</header>';

								if ( $wen_commerce_content || $wen_commerce_more_button ) {
									if ( $wen_commerce_more_button ) {
										$wen_commerce_content .= '<p>
											<a class="more-link" href="' . esc_url( $wen_commerce_link ) . '" rel="bookmark" target="' . esc_attr( $wen_commerce_target ) . '">' . esc_html( $wen_commerce_more_button ) . '</a>
										</p>';
									}

								 	echo '<div class="entry-summary">' . wp_kses_post( wpautop( $wen_commerce_content ) ) . '</div><!-- .entry-summary -->';
								}

								wen_commerce_team_social_links( $wen_commerce_i );	

								echo '
							</div><!-- .entry-container -->';
						}

						echo '
						</div>
					</article><!-- .team-post-' . esc_attr( $wen_commerce_i ) . ' -->';
				} // End for(). 
			} else {
				$wen_commerce_post_list  = array();
				$wen_commerce_no_of_post = 0;

				$wen_commerce_args = array(
					'post_type'           => 'post',
					'ignore_sticky_posts' => 1, // ignore sticky posts.
				);

				// Get valid number of posts.
				if ( 'post' === $wen_commerce_type || 'page' === $wen_commerce_type || 'ect-team' === $wen_commerce_type ) {
					$wen_commerce_args['post_type'] = $wen_commerce_type;

					for ( $wen_commerce_i = 1; $wen_commerce_i <= $wen_commerce_number; $wen_commerce_i++ ) {
						$wen_commerce_post_id = '';

						if ( 'post' === $wen_commerce_type ) {
							$wen_commerce_post_id = get_theme_mod( 'wen_commerce_team_post_' . $wen_commerce_i );
						} elseif ( 'page' === $wen_commerce_type ) {
							$wen_commerce_post_id = get_theme_mod( 'wen_commerce_team_page_' . $wen_commerce_i );
						} elseif ( 'ect-team' === $wen_commerce_type ) {
							$wen_commerce_post_id = get_theme_mod( 'wen_commerce_team_cpt_' . $wen_commerce_i );
						}

						if ( $wen_commerce_post_id && '' !== $wen_commerce_post_id ) {
							$wen_commerce_post_list = array_merge( $wen_commerce_post_list, array( $wen_commerce_post_id ) );

							$wen_commerce_no_of_post++;
						}
					}

					$wen_commerce_args['post__in'] = $wen_commerce_post_list;
					$wen_commerce_args['orderby']  = 'post__in';
				} elseif ( 'category' === $wen_commerce_type ) {
					if ( $wen_commerce_cat = get_theme_mod( 'wen_commerce_team_select_category' ) ) {
						$wen_commerce_args['category__in'] = $wen_commerce_cat;
					}

					$wen_commerce_no_of_post = $wen_commerce_number;
				}

				$wen_commerce_args['posts_per_page'] = $wen_commerce_no_of_post;

				$wen_commerce_loop = new WP_Query( $wen_commerce_args );

				if ( $wen_commerce_loop -> have_posts() ) :
					while ( $wen_commerce_loop -> have_posts() ) :
						$wen_commerce_loop -> the_post();

						?>
						<article id="post-<?php the_ID(); ?>" <?php post_class(); ?>>
							<div class="hentry-inner">
								<?php wen_commerce_post_thumbnail( array( 568, 757 ) ); ?>

								<div class="entry-container">
									<header class="entry-header">
										<?php if ( 'show-meta' === $wen_commerce_show_meta ) : ?>
										<div class="entry-meta">
											<?php wen_commerce_cat_list(); ?>
										</div><!-- .entry-meta -->
										<?php endif; ?>

										<?php the_title( '<h2 class="entry-title"><a href="' . esc_url( get_permalink() ) . '" rel="bookmark">','</a></h2>' ); ?>
									</header>

									<?php wen_commerce_content_display( $wen_commerce_show_content ); ?>

									<?php wen_commerce_team_social_links( absint( $wen_commerce_loop->current_post ) + 1 ); ?>
								</div><!-- .entry-container -->
							</div> <!-- .hentry-inner -->
						</article> <!-- .article -->
						<?php
					endwhile;
					wp_reset_postdata();
				endif;
			}
			?>
		</div><!-- .team-wrapper -->
		
		<?php
			$wen_commerce_target        = get_theme_mod( 'wen_commerce_team_target' ) ? '_blank': '_self';
			$wen_commerce_link = get_theme_mod( 'wen_commerce_team_link', '#' );
			$wen_commerce_text          = get_theme_mod( 'wen_commerce_team_text' );

			if ( $wen_commerce_text ) :
		?>

		<p class="view-more">
			<a class="button" target="<?php echo $wen_commerce_target; ?>" href="<?php echo esc_url( $wen_commerce_link ); ?>"><?php echo esc_html( $wen_commerce_text ); ?></a>
		</p>
		<?php endif; ?>

	</div><!-- .wrapper -->
</div><!-- #team-section -->
