<?php
/**
 * The template for displaying Woo Products Showcase
 *
 * @package WEN_Commerce
 */

if ( ! class_exists( 'WooCommerce' ) ) {
    // Bail if WooCommerce is not installed
    return;
}

$wen_commerce_enable_content = get_theme_mod( 'wen_commerce_woo_products_showcase_option', 'disabled' );

if ( ! wen_commerce_check_section( $wen_commerce_enable_content ) ) {
	// Bail if featured content is disabled.
	return;
}

$wen_commerce_number                = get_theme_mod( 'wen_commerce_woo_products_showcase_number', 5 );
$wen_commerce_columns               = get_theme_mod( 'wen_commerce_woo_products_showcase_columns', 5 );
$wen_commerce_paginate              = get_theme_mod( 'wen_commerce_woo_products_showcase_paginate' );
$wen_commerce_orderby = isset( $_GET['orderby'] ) ? $_GET['orderby'] : get_theme_mod( 'wen_commerce_woo_products_showcase_orderby' );
$wen_commerce_product_filter        = get_theme_mod( 'wen_commerce_woo_products_showcase_products_filter' );
$wen_commerce_featured              = get_theme_mod( 'wen_commerce_woo_products_showcase_featured' );
$wen_commerce_order   = get_theme_mod( 'wen_commerce_woo_products_showcase_order' );
$wen_commerce_skus                  = get_theme_mod( 'wen_commerce_woo_products_showcase_skus' );
$wen_commerce_category              = get_theme_mod( 'wen_commerce_woo_products_showcase_category' );

$wen_commerce_shortcode = '[products';

if ( $wen_commerce_number ) {
	$wen_commerce_shortcode .= ' limit="' . esc_attr( $wen_commerce_number ) . '"';
}

if ( $wen_commerce_columns ) {
	$wen_commerce_shortcode .= ' columns="' . absint( $wen_commerce_columns ) . '"';
}

if ( $wen_commerce_paginate ) {
	$wen_commerce_shortcode .= ' paginate="' . esc_attr( $wen_commerce_paginate ) . '"';
}

if ( $wen_commerce_orderby ) {
	$wen_commerce_shortcode .= ' orderby="' . esc_attr( $wen_commerce_orderby ) . '"';
}

if ( $wen_commerce_order ) {
	$wen_commerce_shortcode .= ' order="' . esc_attr( $wen_commerce_order ) . '"';
}

if ( $wen_commerce_product_filter && 'none' !== $wen_commerce_product_filter ) {
	$wen_commerce_shortcode .= ' ' . esc_attr( $wen_commerce_product_filter ) . '="true"';
}

if ( $wen_commerce_skus ) {
	$wen_commerce_shortcode .= ' skus="' . esc_attr( $wen_commerce_skus ) . '"';
}

if ( $wen_commerce_category ) {
	$wen_commerce_shortcode .= ' category="' . esc_attr( $wen_commerce_category ) . '"';
}

if ( $wen_commerce_featured ) {
	$wen_commerce_shortcode .= ' visibility="featured"';
}

$wen_commerce_shortcode .= ']';

$wen_commerce_tagline     = get_theme_mod( 'wen_commerce_woo_products_showcase_tagline');
$wen_commerce_title       = get_theme_mod( 'wen_commerce_woo_products_showcase_title' );
$wen_commerce_description = get_theme_mod( 'wen_commerce_woo_products_showcase_description' );
$wen_commerce_classes[] = 'section';

if ( ! $wen_commerce_tagline && ! $wen_commerce_title && ! $wen_commerce_description ) {
	$wen_commerce_classes[] = 'no-section-heading';
}
?>

<div id="product-content-section" class="product-content-section <?php echo esc_attr( implode( ' ', $wen_commerce_classes ) ); ?>">
	<div class="wrapper">
		<?php if ( $wen_commerce_tagline || $wen_commerce_title || $wen_commerce_description ) : ?>
			<div class="section-heading-wrapper">

				<?php if( $wen_commerce_tagline ) : ?>
					<div class="section-subtitle">
						<?php echo esc_html( $wen_commerce_tagline ); ?>
					</div>
				<?php endif; ?>

				<?php if ( $wen_commerce_title ) : ?>
					<div class="section-title-wrapper">
						<h2 class="section-title"><?php echo wp_kses_post( $wen_commerce_title ); ?></h2>
					</div><!-- .page-title-wrapper -->
				<?php endif; ?>

				<?php if ( $wen_commerce_description ) : ?>
					<div class="section-description">
						<p>
							<?php
								echo wp_kses_post( $wen_commerce_description );
							?>
						</p>
					</div><!-- .section-description-wrapper -->
				<?php endif; ?>
			</div><!-- .section-heading-wrapper -->
		<?php endif; ?>

		<div class="section-content-wrapper product-content-wrapper">
			<?php echo do_shortcode( $wen_commerce_shortcode ); ?>
		</div><!-- .section-content-wrapper -->

		<?php
			$wen_commerce_target = get_theme_mod( 'wen_commerce_woo_products_showcase_target' ) ? '_blank': '_self';
			$wen_commerce_link   = get_theme_mod( 'wen_commerce_woo_products_showcase_link' );
			$wen_commerce_text   = get_theme_mod( 'wen_commerce_woo_products_showcase_text' );

			if ( $wen_commerce_text ) :
		?>
			<p class="view-more">
				<a class="button" target="<?php echo $wen_commerce_target; ?>" href="<?php echo esc_url( $wen_commerce_link ); ?>"><?php echo esc_html( $wen_commerce_text ); ?></a>
			</p>
		<?php endif; ?>
	</div><!-- .wrapper -->
</div><!-- .sectionr -->
